pub struct DeleteCustomRoleRequest {
pub role_id: String,
pub resource_version: String,
pub async_operation_id: String,
}Fields
role_id: StringThe ID of the custom role to delete.
resource_version: StringThe version of the custom role for which this delete is intended. The latest version can be found in the GetCustomRole operation response.
async_operation_id: StringThe ID to use for this async operation. Optional, if not provided a random ID will be generated.