UserGroupNamespaceAssignment

Struct UserGroupNamespaceAssignment 

pub struct UserGroupNamespaceAssignment {
    pub id: String,
    pub display_name: String,
    pub namespace_access: Option<NamespaceAccess>,
    pub inherited_access: bool,
    pub resource_version: String,
}

Fields

id: String

The ID of the group.

display_name: String

The display name of the group.

namespace_access: Option<NamespaceAccess>

The access assigned to the group at the namespace level.

inherited_access: bool

True if the group has inherited access to the namespace through an account or project role.

resource_version: String

The current resource version of the group.