pub struct UserNamespaceAssignment {
pub id: String,
pub email: String,
pub namespace_access: Option<NamespaceAccess>,
pub inherited_access: bool,
pub resource_version: String,
}Fields
id: StringThe ID of the user.
email: StringThe email of the user.
namespace_access: Option<NamespaceAccess>The access assigned to the user at the namespace level.
inherited_access: boolTrue if the user has inherited access to the namespace through an account or project role.
resource_version: StringThe current resource version of the user.