Attributes

Enum Attributes 

pub enum Attributes {
Show 17 variants ScheduleActivityTaskCommandAttributes(ScheduleActivityTaskCommandAttributes), StartTimerCommandAttributes(StartTimerCommandAttributes), CompleteWorkflowExecutionCommandAttributes(CompleteWorkflowExecutionCommandAttributes), FailWorkflowExecutionCommandAttributes(FailWorkflowExecutionCommandAttributes), RequestCancelActivityTaskCommandAttributes(RequestCancelActivityTaskCommandAttributes), CancelTimerCommandAttributes(CancelTimerCommandAttributes), CancelWorkflowExecutionCommandAttributes(CancelWorkflowExecutionCommandAttributes), RequestCancelExternalWorkflowExecutionCommandAttributes(RequestCancelExternalWorkflowExecutionCommandAttributes), RecordMarkerCommandAttributes(RecordMarkerCommandAttributes), ContinueAsNewWorkflowExecutionCommandAttributes(ContinueAsNewWorkflowExecutionCommandAttributes), StartChildWorkflowExecutionCommandAttributes(StartChildWorkflowExecutionCommandAttributes), SignalExternalWorkflowExecutionCommandAttributes(SignalExternalWorkflowExecutionCommandAttributes), UpsertWorkflowSearchAttributesCommandAttributes(UpsertWorkflowSearchAttributesCommandAttributes), ProtocolMessageCommandAttributes(ProtocolMessageCommandAttributes), ModifyWorkflowPropertiesCommandAttributes(ModifyWorkflowPropertiesCommandAttributes), ScheduleNexusOperationCommandAttributes(ScheduleNexusOperationCommandAttributes), RequestCancelNexusOperationCommandAttributes(RequestCancelNexusOperationCommandAttributes),
}
The command details. The type must match that in command_type.

Variants



ScheduleActivityTaskCommandAttributes(ScheduleActivityTaskCommandAttributes)



StartTimerCommandAttributes(StartTimerCommandAttributes)



CompleteWorkflowExecutionCommandAttributes(CompleteWorkflowExecutionCommandAttributes)



FailWorkflowExecutionCommandAttributes(FailWorkflowExecutionCommandAttributes)



RequestCancelActivityTaskCommandAttributes(RequestCancelActivityTaskCommandAttributes)



CancelTimerCommandAttributes(CancelTimerCommandAttributes)



CancelWorkflowExecutionCommandAttributes(CancelWorkflowExecutionCommandAttributes)



RequestCancelExternalWorkflowExecutionCommandAttributes(RequestCancelExternalWorkflowExecutionCommandAttributes)



RecordMarkerCommandAttributes(RecordMarkerCommandAttributes)



ContinueAsNewWorkflowExecutionCommandAttributes(ContinueAsNewWorkflowExecutionCommandAttributes)



StartChildWorkflowExecutionCommandAttributes(StartChildWorkflowExecutionCommandAttributes)



SignalExternalWorkflowExecutionCommandAttributes(SignalExternalWorkflowExecutionCommandAttributes)



UpsertWorkflowSearchAttributesCommandAttributes(UpsertWorkflowSearchAttributesCommandAttributes)



ProtocolMessageCommandAttributes(ProtocolMessageCommandAttributes)



ModifyWorkflowPropertiesCommandAttributes(ModifyWorkflowPropertiesCommandAttributes)

16 is available for use - it was used as part of a prototype that never made it into a release



ScheduleNexusOperationCommandAttributes(ScheduleNexusOperationCommandAttributes)



RequestCancelNexusOperationCommandAttributes(RequestCancelNexusOperationCommandAttributes)

Implementations

Source

impl Attributes

pub fn encode(&self, buf: &mut impl BufMut)

Encodes the message to a buffer.

pub fn merge( field: &mut Option<Attributes>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>

Decodes an instance of the message from a buffer, and merges it into self.

pub fn encoded_len(&self) -> usize

Returns the encoded length of the message without a length delimiter.