pub struct Internal {
pub data: Vec<u8>,
}Expand description
Callbacks to be delivered internally within the system. This variant is not settable in the API and will be rejected by the service with an INVALID_ARGUMENT error. The only reason that this is exposed is because callbacks are replicated across clusters via the WorkflowExecutionStarted event, which is defined in the public API.
Fields
data: Vec<u8>Opaque internal data.