pub struct ComputeConfig {
pub scaling_groups: HashMap<String, ComputeConfigScalingGroup>,
}Expand description
ComputeConfig stores configuration that helps a worker control plane controller understand when and how to respond to worker lifecycle events.
Fields
scaling_groups: HashMap<String, ComputeConfigScalingGroup>Each scaling group describes a compute config for a specific subset of the worker deployment version: covering a specific set of task types and/or regions. Having different configurations for different task types, allows independent tuning of activity and workflow task processing (for example).
The key of the map is the ID of the scaling group used to reference it in subsequent update calls.