pub struct ComputeConfigScalingGroupUpdate {
pub scaling_group: Option<ComputeConfigScalingGroup>,
pub update_mask: Option<FieldMask>,
}Fields
scaling_group: Option<ComputeConfigScalingGroup>update_mask: Option<FieldMask>Controls which fields from scaling_group will be applied. Semantics:
- Mask is ignored for new scaling groups (only applicable when scaling group already exists).
- Empty mask for an existing scaling group is no-op: no change.
- Non-empty mask for an existing scaling group will update/unset only to the fields mentioned in the mask.
- Accepted paths: “task_queue_types”, “provider”, “provider.type”, “provider.details”, “provider.nexus_endpoint”, “scaler”, “scaler.type”, “scaler.details”