pub struct ComputeProvider {
pub type: String,
pub details: Option<Payload>,
pub nexus_endpoint: String,
}Expand description
ComputeProvider stores information used by a worker control plane controller to respond to worker lifecycle events. For example, when a Task is received on a TaskQueue that has no active pollers, a serverless worker lifecycle controller might need to invoke an AWS Lambda Function that itself ends up calling the SDK’s worker.New() function.
Fields
type: StringType of the compute provider. This string is implementation-specific and can be used by implementations to understand how to interpret the contents of the provider_details field.
details: Option<Payload>Contains provider-specific instructions and configuration. For server-implemented providers, use the SDK’s default content converter to ensure the server can understand it. For remote-implemented providers, you might use your own content converters according to what the remote endpoints understand.
nexus_endpoint: StringOptional. If the compute provider is a Nexus service, this should point there.