#[repr(i32)]pub enum RateLimitSource {
Unspecified = 0,
Api = 1,
Worker = 2,
System = 3,
}Expand description
Source for the effective rate limit.
Variants
Unspecified = 0
Api = 1
The value was set by the API.
Worker = 2
The value was set by a worker.
System = 3
The value was set as the system default.
Implementations
Sourceimpl RateLimitSource
impl RateLimitSource
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.