#[repr(i32)]pub enum RoutingConfigUpdateState {
Unspecified = 0,
InProgress = 1,
Completed = 2,
}Expand description
Indicates whether a change to the Routing Config has been propagated to all relevant Task Queues and their partitions.
Variants
Unspecified = 0
InProgress = 1
Update to the RoutingConfig is currently in progress.
Completed = 2
Update to the RoutingConfig has completed successfully.
Implementations
Sourceimpl RoutingConfigUpdateState
impl RoutingConfigUpdateState
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of RoutingConfigUpdateState.
Sourcepub fn from_i32(value: i32) -> Option<RoutingConfigUpdateState>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<RoutingConfigUpdateState>
Use the TryFrom<i32> implementation instead
Converts an i32 to a RoutingConfigUpdateState, or None if value is not a valid variant.
Sourceimpl RoutingConfigUpdateState
impl RoutingConfigUpdateState
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.