#[repr(i32)]pub enum TaskReachability {
Unspecified = 0,
NewWorkflows = 1,
ExistingWorkflows = 2,
OpenWorkflows = 3,
ClosedWorkflows = 4,
}Expand description
Specifies which category of tasks may reach a worker on a versioned task queue. Used both in a reachability query and its response. Deprecated.
Variants
Unspecified = 0
NewWorkflows = 1
There’s a possiblity for a worker to receive new workflow tasks. Workers should not be retired.
ExistingWorkflows = 2
There’s a possiblity for a worker to receive existing workflow and activity tasks from existing workflows. Workers should not be retired. This enum value does not distinguish between open and closed workflows.
OpenWorkflows = 3
There’s a possiblity for a worker to receive existing workflow and activity tasks from open workflows. Workers should not be retired.
ClosedWorkflows = 4
There’s a possiblity for a worker to receive existing workflow tasks from closed workflows. Workers may be retired dependending on application requirements. For example, if there’s no need to query closed workflows.
Implementations
Sourceimpl TaskReachability
impl TaskReachability
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of TaskReachability.
Sourcepub fn from_i32(value: i32) -> Option<TaskReachability>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<TaskReachability>
Use the TryFrom<i32> implementation instead
Converts an i32 to a TaskReachability, or None if value is not a valid variant.
Sourceimpl TaskReachability
impl TaskReachability
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.