pub struct PollerGroupsInfo {
pub version: i64,
pub poller_groups: Vec<PollerGroupInfo>,
}Expand description
A versioned snapshot of the poller groups the client should use for future polls to a task queue. The version is monotonically increasing so that a client can ignore a snapshot that is older than the one it has already applied.
Fields
version: i64Monotonically increasing version of this snapshot. A client should ignore any snapshot whose version is not greater than the one it last applied.
poller_groups: Vec<PollerGroupInfo>The weighted list of poller groups the client should use for future polls to this task queue.