pub struct PollActivityTaskQueueRequest {
pub namespace: String,
pub task_queue: Option<TaskQueue>,
pub poller_group_id: String,
pub identity: String,
pub worker_instance_key: String,
pub worker_control_task_queue: String,
pub task_queue_metadata: Option<TaskQueueMetadata>,
pub worker_version_capabilities: Option<WorkerVersionCapabilities>,
pub deployment_options: Option<WorkerDeploymentOptions>,
}Fields
namespace: Stringtask_queue: Option<TaskQueue>poller_group_id: StringUnless this is the first poll, the client must pass one of the poller group IDs received in
poller_group_infos of the last the PollActivityTaskQueueResponse according to the
instructions. If not set, the poll is routed randomly which can cause it to be blocked
without receiving a task while the queue actually has tasks in another server location.
identity: StringThe identity of the worker/client
worker_instance_key: StringA unique key for this worker instance, used for tracking worker lifecycle. This is guaranteed to be unique, whereas identity is not guaranteed to be unique.
worker_control_task_queue: StringA dedicated per-worker Nexus task queue on which the server sends control tasks (e.g. activity cancellation) to this specific worker instance.
task_queue_metadata: Option<TaskQueueMetadata>worker_version_capabilities: Option<WorkerVersionCapabilities>Information about this worker’s build identifier and if it is choosing to use the versioning
feature. See the WorkerVersionCapabilities docstring for more.
Deprecated. Replaced by deployment_options.
deployment_options: Option<WorkerDeploymentOptions>Worker deployment options that user has set in the worker.