pub struct PollNexusTaskQueueRequest {
pub namespace: String,
pub task_queue: Option<TaskQueue>,
pub poller_group_id: String,
pub identity: String,
pub worker_instance_key: String,
pub worker_version_capabilities: Option<WorkerVersionCapabilities>,
pub deployment_options: Option<WorkerDeploymentOptions>,
pub worker_heartbeat: Vec<WorkerHeartbeat>,
}Fields
namespace: Stringtask_queue: Option<TaskQueue>poller_group_id: StringUnless this is the first poll, the client must pass one of the poller group IDs received in
poller_group_infos of the last the PollNexusTaskQueueResponse according to the
instructions. If not set, the poll is routed randomly which can cause it to be blocked
without receiving a task while the queue actually has tasks in another server location.
identity: StringThe identity of the client who initiated this request.
worker_instance_key: StringA unique key for this worker instance, used for tracking worker lifecycle. This is guaranteed to be unique, whereas identity is not guaranteed to be unique.
worker_version_capabilities: Option<WorkerVersionCapabilities>Information about this worker’s build identifier and if it is choosing to use the versioning
feature. See the WorkerVersionCapabilities docstring for more.
Deprecated. Replaced by deployment_options.
deployment_options: Option<WorkerDeploymentOptions>Worker deployment options that user has set in the worker.
worker_heartbeat: Vec<WorkerHeartbeat>Worker info to be sent to the server.