pub struct RespondActivityTaskFailedByIdRequest {
pub namespace: String,
pub workflow_id: String,
pub run_id: String,
pub activity_id: String,
pub failure: Option<Failure>,
pub identity: String,
pub last_heartbeat_details: Option<Payloads>,
pub resource_id: String,
}Fields
namespace: StringNamespace of the workflow which scheduled this activity
workflow_id: StringId of the workflow which scheduled this activity, leave empty to target a standalone activity
run_id: StringFor a workflow activity - the run ID of the workflow which scheduled this activity. For a standalone activity - the run ID of the activity.
activity_id: StringId of the activity to fail
failure: Option<Failure>Detailed failure information
identity: StringThe identity of the worker/client
last_heartbeat_details: Option<Payloads>Additional details to be stored as last activity heartbeat
resource_id: StringResource ID for routing. Contains “workflow:workflow_id” or “activity:activity_id” for standalone activities.