pub struct UpdateActivityExecutionOptionsRequest {
pub namespace: String,
pub workflow_id: String,
pub activity_id: String,
pub run_id: String,
pub identity: String,
pub activity_options: Option<ActivityOptions>,
pub update_mask: Option<FieldMask>,
pub restore_original: bool,
pub resource_id: String,
}Fields
namespace: StringNamespace of the workflow which scheduled this activity
workflow_id: StringIf provided, targets a workflow activity for the given workflow ID. If empty, targets a standalone activity.
activity_id: StringThe ID of the activity to target.
run_id: StringRun ID of the workflow or standalone activity.
identity: StringThe identity of the client who initiated this request
activity_options: Option<ActivityOptions>Activity options. Partial updates are accepted and controlled by update_mask
update_mask: Option<FieldMask>Controls which fields from activity_options will be applied
restore_original: boolIf set, the activity options will be restored to the default. Default options are then options activity was created with. They are part of the first schedule event. This flag cannot be combined with any other option; if you supply restore_original together with other options, the request will be rejected.
resource_id: StringResource ID for routing. Contains “workflow:{workflow_id}” for workflow activities or “activity:{activity_id}” for standalone activities.