Compiled protobuf definitions for the Temporal Rust SDK.
Re-exports
pub use protos::*;
Modules
- protos
- Contains the protobuf definitions used as arguments to and return values from interactions with the Temporal Core SDK. Language SDK authors can generate structs using the proto definitions that will match the generated structs in this module.