pub struct UserGroupNamespaceAssignment {
pub id: String,
pub display_name: String,
pub namespace_access: Option<NamespaceAccess>,
pub inherited_access: bool,
pub resource_version: String,
}Fields
id: StringThe ID of the group.
display_name: StringThe display name of the group.
namespace_access: Option<NamespaceAccess>The access assigned to the group at the namespace level.
inherited_access: boolTrue if the group has inherited access to the namespace through an account or project role.
resource_version: StringThe current resource version of the group.